// The 7-bit device address of my SSD1306 and SH1106 controllers is 0x3c
// Sometimes demented hardware designers shift this left by a bit
// and mark their boards 0x7A (!).
// If yours is marked 0x7B or 0x3D, change the definition below to 3d
#define I2C_ADDR7 0x3c

#include <Wire.h>
#include <U8x8lib.h> // In U8g2 library 

// Expansion board uses SSD1306
U8X8_SSD1306_128X64_NONAME_HW_I2C u8x8(/* reset=*/ U8X8_PIN_NONE);

// Dave's breadboard uses SH1106
//U8X8_SH1106_128X64_NONAME_HW_I2C u8x8(/* reset=*/ U8X8_PIN_NONE);

void setup(void) {
  pinMode(LED_BUILTIN, OUTPUT);
  
  Serial.begin(115200);
  // Wait until the connection is made
  while (!Serial);
  delay(100);// Give things a little time to settle down 
  
  Serial.println("\nOLED Test Compiled by davekw7x on " __DATE__ " at " __TIME__);
   
  #ifdef U8X8_HAVE_HW_I2C
  Serial.println("U8X8_HAVE_HW_I2C is defined");
  #else
  Serial.println("U8X8_HAVE_HW_I2C is not defined");
  #endif
  
  Wire.begin();
  Wire.beginTransmission(I2C_ADDR7); 
  uint8_t err = Wire.endTransmission();

  // If you have the correct device address and if the hardware is all OK
  // the result should be zero.
  Serial.print("I2C transmission to 0x"); Serial.print(I2C_ADDR7, HEX);
  Serial.print(" returned "); Serial.print(err);
  Serial.print(" at "); Serial.println(millis());

  u8x8.begin();
  
  // To rotate the output by 180 degrees, set flip mode to 3.
  u8x8.setFlipMode(1);
  
  u8x8.setFont(u8x8_font_chroma48medium8_r);
  u8x8.clear();
  u8x8.setPowerSave(0);
  Serial.print("End of setup() at "); Serial.println(millis());
}
 
void loop(void) {
  static uint8_t count = 0;

  // Toggle the LED
  digitalWrite(LED_BUILTIN, !digitalRead(LED_BUILTIN));

  // If I2C is correctly connected to the OLED, you should see a message
  // on the display.
  char pbuf[16];
  snprintf(pbuf, sizeof(pbuf), "%3d: Hi, Dave!", ++count);
  u8x8.drawString(0, 2, pbuf);
  u8x8.refreshDisplay();
  // Print the same message on the Serial Monitor
  Serial.println(pbuf);
  delay(1000);
}
